'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-2a6e6244.js');
const index_esm_min = require('./index.esm.min-5be3f6d6.js');

const bpSdkDriverGroupCss = "";

let BpSdkDriverGroup = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.deleteItem = index.createEvent(this, "deleteItem", 7);
    /**
     * Can delete
     */
    this.canDelete = false;
    /**
     * Error states
     */
    this.errors = {};
    this.isDriverValid = true;
    this.driverName = '';
    this.labelId = index_esm_min.fx(8);
    this.useExternal = false;
    this.isExpanded = true;
    this.slotId = index_esm_min.fx(8);
    this.onToggleExpansion = () => {
      this.isExpanded = !this.isExpanded;
    };
    this.onDeleteButtonClick = () => this.deleteItem.emit();
  }
  onGroupChange(group) {
    this.updateDriverValidity(group, this.errors);
    this.updateDriverName(group);
  }
  onErrorsChange(errors) {
    this.updateDriverValidity(this.group, errors);
  }
  updateDriverName(group) {
    var _a, _b, _c, _d, _e, _f;
    if (!group) {
      return;
    }
    const firstName = (_b = (_a = index_esm_min.pL('mqs_driver_first_name', group.answers)) === null || _a === void 0 ? void 0 : _a.value) !== null && _b !== void 0 ? _b : '';
    const lastName = (_d = (_c = index_esm_min.pL('mqs_driver_last_name', group.answers)) === null || _c === void 0 ? void 0 : _c.value) !== null && _d !== void 0 ? _d : '';
    let name = group.label;
    if (firstName && lastName) {
      name = `${firstName} ${lastName}`;
    }
    if ((_e = group.parentQuestionAnswer) === null || _e === void 0 ? void 0 : _e.value) {
      name = (_f = group.parentQuestionAnswer) === null || _f === void 0 ? void 0 : _f.value;
    }
    this.driverName = name || 'Driver';
  }
  updateDriverValidity(group, errors) {
    var _a;
    this.isDriverValid = index_esm_min.s4(group) && !!((_a = group.answers) === null || _a === void 0 ? void 0 : _a.reduce((acc, answer) => { var _a; return acc && !((_a = errors[answer.question.id]) === null || _a === void 0 ? void 0 : _a.length); }, true));
  }
  resetState() {
    this.driverName = '';
    this.isDriverValid = true;
  }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-driver-group');
    customElements.whenDefined('bp-sdk-external-driver-group').then(() => {
      this.useExternal = true;
    });
    this.updateDriverValidity(this.group, this.errors);
    this.updateDriverName(this.group);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return index.h("bp-sdk-external-driver-group", { group: this.group, errors: this.errors, canDelete: this.canDelete });
  }
  renderInternal() {
    var _a;
    const iconName = this.isDriverValid ? 'person' : 'error-outline';
    return (index.h("div", { class: "bp-sdk-driver-group__container" }, index.h("bp-sdk-icon-container", { name: iconName }), index.h("span", { id: this.labelId, class: "bp-sdk-driver-group__name", slot: `${this.slotId}-label`, onClick: this.onToggleExpansion }, this.driverName), this.canDelete && (index.h("button", { type: "button", class: "bp-sdk-driver-group__delete-button", slot: `${this.slotId}-label--after`, onClick: this.onDeleteButtonClick }, "Delete")), index.h("bp-sdk-dynamic-input-list", { answers: (_a = this.group) === null || _a === void 0 ? void 0 : _a.answers, labelledBy: this.labelId })));
  }
  static get watchers() { return {
    "group": ["onGroupChange"],
    "errors": ["onErrorsChange"]
  }; }
};
BpSdkDriverGroup.style = bpSdkDriverGroupCss;

const bpSdkDynamicInputListCss = "";

let BpSdkDynamicInputList = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * Answer list
     */
    this.answers = [];
    this.useExternal = false;
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-dynamic-input-list');
    customElements.whenDefined('bp-sdk-external-dynamic-input-list').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return index.h("bp-sdk-external-dynamic-input-list", { answers: this.answers, labelledBy: this.labelledBy });
  }
  renderInternal() {
    var _a;
    return (index.h("div", { class: "bp-sdk-dynamic-input-list__container" }, (_a = this.answers) === null || _a === void 0 ? void 0 : _a.map((answer) => (index.h("bp-sdk-dynamic-input-redux-container", { code: answer.question.code, answer: answer, labelledBy: this.labelledBy })))));
  }
};
BpSdkDynamicInputList.style = bpSdkDynamicInputListCss;

exports.bp_sdk_driver_group = BpSdkDriverGroup;
exports.bp_sdk_dynamic_input_list = BpSdkDynamicInputList;
