'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-2a6e6244.js');
const index_esm_min = require('./index.esm.min-d07c5def.js');
const index_esm_min$1 = require('./index.esm.min-5be3f6d6.js');
const sdkRedux = require('@boldpenguin/sdk-redux');
const store = require('./store-fe3d3434.js');
const debounce = require('./debounce-5ee836a2.js');
const isEqual = require('./isEqual-30f1b2bc.js');
require('./_commonjsHelpers-bcc1208a.js');

const bpSdkVehicleGroupCss = "";

let BpSdkVehicleGroup = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.saveVehicle = index.createEvent(this, "saveVehicle", 7);
    /**
     * Can Save
     */
    this.canSave = true;
    /**
     * Is vehicle trailer
     */
    this.isVehicleTrailer = false;
    /**
     * Should show trailers
     */
    this.shouldShowTrailers = true;
    this.useExternal = false;
    this.selectedCAFlow = 'none';
    this.saveButtonClick = () => {
      switch (this.selectedCAFlow) {
        case index_esm_min.T.ymm:
          this.saveVehicle.emit(index_esm_min.T.ymm);
          break;
        case index_esm_min.T.vin:
          this.saveVehicle.emit(index_esm_min.T.vin);
          break;
        case 'trailer':
          this.saveVehicle.emit(index_esm_min.T.trailers);
          break;
      }
    };
  }
  onQuestionSetChange(questionGroup) {
    this.flowAnswer = index_esm_min$1.ec(questionGroup);
    this.selectedCAFlow = this.getSelectedVehicleInput();
  }
  resetState() {
    this.flowAnswer = index_esm_min$1.ec(this.questionGroup);
  }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-group');
    customElements.whenDefined('bp-sdk-external-vehicle-group').then(() => {
      this.useExternal = true;
    });
    this.onQuestionSetChange(this.questionGroup);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderVehicleQuestions() {
    switch (this.selectedCAFlow) {
      case 'ymm':
        return index.h("bp-sdk-vehicle-interface", { questionGroup: this.questionGroup, canSave: this.canSave });
      case 'vin':
        return index.h("bp-sdk-vehicle-vin-container", { questionGroupId: index_esm_min$1.s9(this.questionGroup) });
      case 'trailer':
        return this.shouldShowTrailers ? (index.h("bp-sdk-vehicle-interface", { questionGroup: this.questionGroup, isVehicleTrailer: true, canSave: this.canSave })) : ('');
      default:
        return '';
    }
  }
  renderExternal() {
    return (index.h("bp-sdk-external-vehicle-group", { canSave: this.canSave, isVehicleTrailer: this.isVehicleTrailer, questionGroup: this.questionGroup, shouldShowTrailers: this.shouldShowTrailers, handleDelete: this.handleDelete }));
  }
  renderInternal() {
    return (index.h("div", { class: "bp-sdk-vehicle-group__container" }, index.h("h2", null, "Vehicle Information"), index.h("bp-sdk-dynamic-input-redux-container", { answer: this.flowAnswer, label: "Choose how to add your vehicle" }), this.renderVehicleQuestions(), index.h("div", { class: "bp-sdk-row" }, index.h("bp-sdk-vehicle-delete-button", { onClick: this.handleDelete }), index.h("bp-sdk-vehicle-save-button", { buttonDisabled: !this.canSave, onClick: this.saveButtonClick, text: "Save Vehicle" }))));
  }
  getSelectedVehicleInput() {
    var _a;
    if (!this.flowAnswer) {
      return 'none';
    }
    const selectedCAFlow = this.flowAnswer.choice_id;
    const aliasOfSelectedChoice = (_a = this.flowAnswer.question.choices.find((choice) => choice.id === selectedCAFlow)) === null || _a === void 0 ? void 0 : _a.value;
    switch (aliasOfSelectedChoice) {
      case 'Year / Make / Model':
        return 'ymm';
      case 'VIN':
        return 'vin';
      case 'Trailer':
        return 'trailer';
      default:
        return 'none';
    }
  }
  static get watchers() { return {
    "questionGroup": ["onQuestionSetChange"]
  }; }
};
BpSdkVehicleGroup.style = bpSdkVehicleGroupCss;

const bpSdkVehiclePanelCss = "";

let BpSdkVehiclePanel = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * Non-vehicle specific answers
     */
    this.answers = [];
    /**
     * Can edit
     */
    this.canEdit = false;
    /**
     * Is editing
     */
    this.isEditing = false;
    /**
     * Is expanded
     */
    this.isExpanded = true;
    /**
     * Can Delete
     */
    this.canDelete = false;
    /**
     * Can Save
     */
    this.canSave = true;
    /**
     * Is vehicle valid
     */
    this.isValid = true;
    /**
     * Vehicle information
     */
    this.vehicleInformation = { year: '', make: '', model: '', configuration: '' };
    /**
     * Default "Add new vehicle" label text
     */
    this.vehicleLabel = 'Add new vehicle';
    /**
     * should show trailers?
     */
    this.shouldShowTrailers = false;
    /**
     * Is vehicle trailer?
     */
    this.isVehicleTrailer = false;
    this.useExternal = false;
    this.icon = '';
    this.ids = {
      year: index_esm_min$1.fx(8),
      make: index_esm_min$1.fx(8),
      model: index_esm_min$1.fx(8),
      slot: index_esm_min$1.fx(8),
    };
    this.onClick = () => {
      if (this.isExpanded) {
        this.handleClose();
      }
      else {
        this.handleOpen();
      }
    };
  }
  onIsValidChange(isValid) {
    this.icon = isValid ? 'check_circle' : 'error_outline';
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-panel');
    customElements.whenDefined('bp-sdk-external-vehicle-panel').then(() => {
      this.useExternal = true;
    });
  }
  onVehicleInformationChange(vehicleInformation) {
    this.labelledBy = index_esm_min$1.ix('', {
      [this.ids.year]: !!vehicleInformation.year,
      [this.ids.make]: !!vehicleInformation.make,
      [this.ids.model]: !!vehicleInformation.model,
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (index.h("bp-sdk-external-vehicle-panel", { answers: this.answers, canDelete: this.canDelete, canEdit: this.canEdit, canSave: this.canSave, code: this.code, handleClose: this.handleClose, handleDelete: this.handleDelete, handleEdit: this.handleEdit, handleOpen: this.handleOpen, isEditing: this.isEditing, isExpanded: this.isExpanded, isValid: this.isValid, isVehicleTrailer: this.isVehicleTrailer, questionGroup: this.questionGroup, shouldShowTrailers: this.shouldShowTrailers, vehicleInformation: this.vehicleInformation, vehicleLabel: this.vehicleLabel }));
  }
  renderContent() {
    return (index.h("div", { class: "bp-sdk-vehicle-panel__content", slot: `${this.ids.slot}-content` }, this.isValid && (index.h("bp-sdk-vehicle-panel-content", { additionalAnswers: this.answers, questionGroup: this.questionGroup, labelledBy: this.labelledBy }))));
  }
  renderInternal() {
    return (index.h("div", { class: "bp-sdk-vehicle-panel__container" }, this.isEditing && [
      index.h("bp-sdk-vehicle-group", { canSave: this.canSave, questionGroup: this.questionGroup, shouldShowTrailers: this.shouldShowTrailers, isVehicleTrailer: this.isVehicleTrailer, handleDelete: this.handleDelete }),
      this.renderContent(),
    ], !this.isEditing && [
      index.h("bp-sdk-icon-container", { name: this.icon }),
      index.h("bp-sdk-vehicle-panel-label", { class: "bp-sdk-vehicle-panel__label", vehicleLabel: this.vehicleLabel, onClick: this.onClick }),
      index.h("bp-sdk-vehicle-panel-buttons", { class: "bp-sdk-vehicle-panel__buttons", canDelete: this.canDelete, canEdit: this.canEdit, handleDelete: this.handleDelete, handleEdit: this.handleEdit }),
      this.renderContent(),
    ]));
  }
  static get watchers() { return {
    "isValid": ["onIsValidChange"],
    "vehicleInformation": ["onVehicleInformationChange"]
  }; }
};
BpSdkVehiclePanel.style = bpSdkVehiclePanelCss;

const bpSdkVehiclePanelButtonsCss = "";

let BpSdkVehiclePanelButtons = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * Can Delete
     */
    this.canDelete = false;
    /**
     * Can edit
     */
    this.canEdit = false;
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-panel-buttons');
    customElements.whenDefined('bp-sdk-external-vehicle-panel-buttons').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (index.h("bp-sdk-external-vehicle-panel-buttons", { canDelete: this.canDelete, canEdit: this.canEdit, handleDelete: this.handleDelete, handleEdit: this.handleEdit }));
  }
  renderInternal() {
    return (index.h("div", { class: "bp-sdk-vehicle-panel-buttons__container" }, this.canEdit && [
      this.canDelete && index.h("bp-sdk-vehicle-delete-button", { onClick: this.handleDelete }),
      index.h("bp-sdk-vehicle-edit-button", { onClick: this.handleEdit }),
    ]));
  }
};
BpSdkVehiclePanelButtons.style = bpSdkVehiclePanelButtonsCss;

const bpSdkVehiclePanelContainerCss = "";

let BpSdkVehiclePanelContainer = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.deleteItem = index.createEvent(this, "deleteItem", 7);
    this.saveAnswer = index.createEvent(this, "saveAnswer", 7);
    /**
     * Non-vehicle specific answers
     */
    this.answers = [];
    /**
     * Can delete
     */
    this.canDelete = false;
    /**
     * Vehicle options injected by redux
     */
    this.yearOptions = {};
    /**
     * Should show trailers?
     */
    this.shouldShowTrailers = false;
    /**
     * Is vehicle trailer?
     */
    this.isVehicleTrailer = false;
    this.vehicleInformation = {
      year: '',
      make: '',
      model: '',
      configuration: '',
    };
    this.canEdit = true;
    this.canSave = false;
    this.isEditing = false;
    this.isExpanded = true;
    this.isSaving = false;
    this.isValid = true;
    this.useExternal = false;
    this.tabIndex = 0;
    this.vehicleLabel = '';
    this.makeDisplayValue = '';
    this.handleSubscriptions = () => {
      if (store.canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        store.store.mapDispatchToProps(this, {
          loadYears: sdkRedux.loadYears,
          loadMakes: sdkRedux.loadMakes,
          loadModels: sdkRedux.loadModels,
          loadConfigurations: sdkRedux.loadConfigurations,
          loadSingleQuestionSet: sdkRedux.loadSingleQuestionSet,
          loadSingleApplicationForm: sdkRedux.loadSingleApplicationForm,
          selectVehicle: sdkRedux.selectVehicle,
          resetSelectedVehicle: sdkRedux.resetSelectedVehicle,
          loadFullVehicleOptions: sdkRedux.loadFullVehicleOptions,
          setVehicleSelection: sdkRedux.setVehicleSelection,
        });
        this.storeUnsubscribe = store.store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        config: sdkRedux.getPartnerEngineConfig(state),
        appFormId: state.application.form.id,
        yearOptions: sdkRedux.getVehicleOptionsYears(state, this.questionGroupId),
        selectionStatus: sdkRedux.getVehicleSelectionState(state, this.questionGroupId),
        vehicleInformation: sdkRedux.getDisplayFriendlyVehicleOptionsSelection(state, this.questionGroupId),
      };
    };
    this.loadOptions = debounce.debounce_1((selection) => {
      this.loadFullVehicleOptions({
        year: selection.yearId,
        makeId: selection.makeId,
        modelId: selection.modelId,
        config: this.config,
        questionGroupId: this.questionGroupId,
        type: this.type,
      });
      this.setVehicleSelection({
        questionGroupId: this.questionGroupId,
        selection,
      });
    }, 100);
    this.setOptions = debounce.debounce_1((selection) => {
      this.setVehicleSelection({
        questionGroupId: this.questionGroupId,
        selection: Object.assign({ configurationId: undefined, makeId: undefined, modelId: undefined, yearId: undefined }, selection),
      });
    }, 100);
    this.onVehicleSaveCallback = () => {
      this.isSaving = false;
      this.isEditing = false;
      this.onQuestionGroupChange(this.questionGroup);
    };
    this.editVehicle = (e) => {
      e.stopPropagation();
      this.onEdit();
    };
    this.deleteVehicle = () => {
      this.deleteItem.emit(this.code);
      this.selectVehicle({
        answerPoolId: this.questionGroup.poolId,
        appId: this.appFormId,
        questionGroupId: this.questionGroup.groupId,
        configurationId: undefined,
        flowType: index_esm_min.T.ymm,
        config: this.config,
      });
    };
    this.onOpen = () => {
      this.canEdit = true;
      this.isEditing = false;
      this.isExpanded = true;
    };
    this.onClose = () => {
      this.canEdit = false;
      this.isEditing = false;
      this.isExpanded = false;
    };
  }
  resetState() {
    this.canEdit = true;
    this.canSave = false;
    this.isEditing = false;
    this.isExpanded = true;
    this.isValid = true;
    this.type = undefined;
    this.vehicleLabel = '';
    this.makeDisplayValue = '';
  }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-panel-container');
    customElements.whenDefined('bp-sdk-external-vehicle-panel-container').then(() => {
      this.useExternal = true;
    });
    this.onIsVehicleTrailerChanged(this.isVehicleTrailer);
    this.onTabChanged(this.tabIndex);
    this.onQuestionGroupChange(this.questionGroup);
  }
  handleTabChanged({ detail }) {
    if (this.useExternal) {
      return;
    }
    this.tabIndex = detail;
  }
  onTabChanged(tab) {
    this.updateType(tab, this.isVehicleTrailer);
  }
  onIsVehicleTrailerChanged(isVehicleTrailer) {
    this.updateType(this.tabIndex, isVehicleTrailer);
  }
  updateType(tab, isVehicleTrailer) {
    if (this.useExternal) {
      return;
    }
    const type = isVehicleTrailer || this.isTrailerTab(tab) ? index_esm_min.P.trailers : undefined;
    if (type !== this.type) {
      this.setVehicleSelection({
        questionGroupId: this.questionGroupId,
        selection: { yearId: undefined, modelId: undefined, makeId: undefined, configurationId: undefined },
      });
      this.populateVehicleOptions(this.questionGroup);
      this.type = type;
      this.fetchYears();
    }
  }
  isTrailerTab(tab) {
    var _a;
    const flow = index_esm_min$1.ec(this.questionGroup);
    const trailerTab = flow === null || flow === void 0 ? void 0 : flow.question.choices.find((choice) => !!choice.value.match(/trailer/gi));
    const order = (_a = trailerTab === null || trailerTab === void 0 ? void 0 : trailerTab.order) !== null && _a !== void 0 ? _a : 2; // we know what order should be
    return tab === order;
  }
  populateVehicleOptions(questionGroup) {
    var _a, _b, _c, _d;
    const existingVehicleAnswer = (_a = questionGroup === null || questionGroup === void 0 ? void 0 : questionGroup.answers) === null || _a === void 0 ? void 0 : _a.find((ans) => ans.question.reference_type === index_esm_min.u.CommercialAutoJson);
    if (!(existingVehicleAnswer === null || existingVehicleAnswer === void 0 ? void 0 : existingVehicleAnswer.value)) {
      return;
    }
    const vehicleJson = JSON.parse(existingVehicleAnswer.value);
    let year = Number(vehicleJson.year);
    let makeId = (_b = vehicleJson.make_id) === null || _b === void 0 ? void 0 : _b.toString();
    let modelId = (_c = vehicleJson.model_id) === null || _c === void 0 ? void 0 : _c.toString();
    let configurationId = (_d = vehicleJson.configuration_id) === null || _d === void 0 ? void 0 : _d.toString();
    //account for fallthrough free-text values for trailers
    if (vehicleJson.category === 'Trailers') {
      if (!makeId)
        makeId = vehicleJson.make;
      if (!modelId)
        modelId = vehicleJson.model;
    }
    const isValidState = !Number.isNaN(year) && makeId && modelId && (configurationId || vehicleJson.category === 'Trailers');
    this._currentYear = year;
    this._currentMakeId = makeId;
    this._currentModelId = modelId;
    this._currentConfigId = configurationId;
    this.canSave = this.isVehicleInputComplete();
    if (isValidState) {
      this.loadOptions({
        yearId: year,
        makeId,
        modelId,
        configurationId,
      });
    }
  }
  onQuestionGroupChange(questionGroup, oldQuestionGroup) {
    if (this.isSaving || isEqual.isEqual_1(questionGroup, oldQuestionGroup)) {
      return;
    }
    this.questionGroupId = index_esm_min$1.s9(questionGroup);
    this.populateVehicleOptions(questionGroup);
    this.handleSubscriptions();
    this.vehicleLabel = this.getVehicleLabel();
    this.canSave = this.isVehicleInputComplete();
  }
  onVehicleInformationChange(vehicleInformation) {
    this.isValid = !!(vehicleInformation.make && vehicleInformation.model && vehicleInformation.year);
  }
  onOptionsUpdate(updateEvent) {
    var _a;
    const data = updateEvent.detail;
    if (!(data === null || data === void 0 ? void 0 : data.value)) {
      return;
    }
    switch (data.type) {
      case index_esm_min.R.Year:
        const currentYear = Number(data.value);
        if (!Number.isNaN(currentYear) && currentYear) {
          this._currentYear = currentYear;
          this._currentMakeId = undefined;
          this._currentModelId = undefined;
          this._currentConfigId = undefined;
          this.setOptions({ yearId: currentYear });
          this.fetchMakes();
        }
        break;
      case index_esm_min.R.Make:
        this._currentMakeId = data.value;
        this._currentModelId = undefined;
        this._currentConfigId = undefined;
        this.setOptions({ makeId: this._currentMakeId, yearId: this._currentYear });
        this.fetchModels();
        // Needed for free-form answer flows for trailers
        this.makeDisplayValue = (_a = data.displayValue) !== null && _a !== void 0 ? _a : '';
        break;
      case index_esm_min.R.Model:
        this._currentModelId = data.value;
        this._currentConfigId = undefined;
        this.setOptions({
          modelId: this._currentModelId,
          makeId: this._currentMakeId,
          yearId: this._currentYear,
        });
        if (!this.isVehicleTrailer) {
          this.fetchConfigurations();
        }
        break;
      case index_esm_min.R.Configuration:
        this._currentConfigId = data.value;
        this.setOptions({
          configurationId: this._currentConfigId,
          modelId: this._currentModelId,
          makeId: this._currentMakeId,
          yearId: this._currentYear,
        });
        break;
    }
    this.vehicleLabel = this.getVehicleLabel();
    this.canSave = this.isVehicleInputComplete();
  }
  fetchYears() {
    this.loadYears({ config: this.config, questionGroupId: this.questionGroupId });
  }
  fetchMakes() {
    this.loadMakes({
      config: this.config,
      questionGroupId: this.questionGroupId,
      type: this.type,
      year: this._currentYear,
    });
  }
  fetchModels() {
    this.loadModels({
      config: this.config,
      questionGroupId: this.questionGroupId,
      type: this.type,
      year: this._currentYear,
      makeId: this._currentMakeId,
    });
  }
  fetchConfigurations() {
    this.loadConfigurations({
      config: this.config,
      questionGroupId: this.questionGroupId,
      type: this.type,
      year: this._currentYear,
      makeId: this._currentMakeId,
      modelId: this._currentModelId,
    });
  }
  onMakeDirty() {
    if (!this.isValid && !this.isEditing && this.canEdit) {
      this.onEdit();
      setTimeout(() => index_esm_min$1.vx(), 200);
    }
  }
  onVinUpdate(event) {
    const answer = this.questionGroup.answers.find((ans) => ans.id === event.detail.answerId);
    if (answer != null) {
      this.saveAnswer.emit({ answer, new_value: event.detail.vin });
    }
  }
  onVehicleSave(saveEvent) {
    const flowType = saveEvent.detail;
    const isTrailerFlow = flowType === index_esm_min.T.trailers;
    const type = isTrailerFlow ? index_esm_min.T.trailers : undefined;
    const params = {
      answerPoolId: this.questionGroup.poolId,
      appId: this.appFormId,
      questionGroupId: this.questionGroup.groupId,
      configurationId: this._currentConfigId,
      flowType,
      config: this.config,
      type,
      callback: this.onVehicleSaveCallback,
    };
    if (flowType && (isTrailerFlow || this._currentConfigId)) {
      this.isSaving = true;
      if (isTrailerFlow && !this._currentConfigId) {
        /**
         * The vehicle params support the free-form text flow. They will be ignored if params.configurationId is defined.
         * In a free-form flow, PE uses the YMM values as-is, so we always need to pass them as the display values
         * instead of as IDs.
         *
         * The year id always matches the display value, so we can use that in any scenario.
         * If we are in a free-form flow, the model will always be a free-form answer. Therefore the id and display
         * values will match, and we can send the model id.
         * Make can be a dropdown option id or a free-form answer. If it is a dropdown option, the display value is the
         * text value we need to send to PE. If it is a free-form answer, the display value will match the id, and either
         * can be sent to PE. Therefore, we can safely choose the display value for either scenario.
         */
        params.vehicle = {
          yearId: this._currentYear,
          makeId: this.makeDisplayValue,
          modelId: this._currentModelId,
        };
      }
      this.selectVehicle(params);
    }
  }
  onVehicleResourceChange(vehicleSelectionState) {
    if (this.isEditing) {
      switch (vehicleSelectionState) {
        case index_esm_min.i.Loaded:
          this.resetSelectedVehicle({ questionGroupId: this.questionGroup.groupId });
          break;
      }
    }
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  onEdit() {
    if (!this.yearOptions || !Object.keys(this.yearOptions).length) {
      this.fetchYears();
    }
    this.isEditing = true;
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (index.h("bp-sdk-external-vehicle-panel-container", { answers: this.answers, appFormId: this.appFormId, canDelete: this.canDelete, code: this.code, config: this.config, isVehicleTrailer: this.isVehicleTrailer, questionGroup: this.questionGroup, selectionStatus: this.selectionStatus, shouldShowTrailers: this.shouldShowTrailers, yearOptions: this.yearOptions, vehicleInformation: this.vehicleInformation, vehicleLabel: this.vehicleLabel }));
  }
  renderInternal() {
    return (index.h("bp-sdk-vehicle-panel", { answers: this.answers, canDelete: this.canDelete, canEdit: this.canEdit, canSave: this.canSave, code: this.code, handleClose: this.onClose, handleDelete: this.deleteVehicle, handleEdit: this.editVehicle, handleOpen: this.onOpen, isEditing: this.isEditing, isExpanded: this.isExpanded, isValid: this.isValid, questionGroup: this.questionGroup, isVehicleTrailer: this.isVehicleTrailer, shouldShowTrailers: this.shouldShowTrailers, vehicleInformation: this.vehicleInformation, vehicleLabel: this.vehicleLabel }));
  }
  getVehicleLabel() {
    var _a, _b, _c;
    // This is the anchor question. Its value should be the full vehicle name
    return (_c = (_b = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.parentQuestionAnswer) === null || _b === void 0 ? void 0 : _b.value) !== null && _c !== void 0 ? _c : '';
  }
  isVehicleInputComplete() {
    const hasTrailerValues = !!this._currentYear && !!this._currentMakeId && !!this._currentModelId;
    const canSaveTrailer = this.isVehicleTrailer && hasTrailerValues;
    return canSaveTrailer || !!this._currentConfigId;
  }
  get el() { return index.getElement(this); }
  static get watchers() { return {
    "tabIndex": ["onTabChanged"],
    "isVehicleTrailer": ["onIsVehicleTrailerChanged"],
    "questionGroup": ["onQuestionGroupChange"],
    "vehicleInformation": ["onVehicleInformationChange"],
    "selectionStatus": ["onVehicleResourceChange"]
  }; }
};
BpSdkVehiclePanelContainer.style = bpSdkVehiclePanelContainerCss;

const bpSdkVehiclePanelContentCss = "";

let BpSdkVehiclePanelContent = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * Additional answers for a vehicle after the vehicle is saved/valid
     */
    this.additionalAnswers = [];
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-panel-content');
    customElements.whenDefined('bp-sdk-external-vehicle-panel-content').then(() => {
      this.useExternal = true;
    });
  }
  shouldRenderQuestionGroup(questionGroupsWithAnswersAsKey, answer) {
    return questionGroupsWithAnswersAsKey.has(answer.id);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (index.h("bp-sdk-external-vehicle-panel-content", { additionalAnswers: this.additionalAnswers, labelledBy: this.labelledBy, questionGroup: this.questionGroup }));
  }
  renderInternal() {
    return this.additionalAnswers.map((answer) => {
      return this.renderAnswer(answer);
    });
  }
  renderAnswer(answer) {
    var _a, _b;
    if (!answer) {
      return null;
    }
    const nestedGroupToRender = (_b = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.nestedGroupsWithAnswers) === null || _b === void 0 ? void 0 : _b.get(answer.id);
    return [
      !nestedGroupToRender && index.h("bp-sdk-dynamic-input-redux-container", { answer: answer }),
      nestedGroupToRender && index.h("bp-sdk-question-group-container", { questionGroup: nestedGroupToRender }),
    ];
  }
};
BpSdkVehiclePanelContent.style = bpSdkVehiclePanelContentCss;

const bpSdkVehiclePanelLabelCss = "";

let BpSdkVehiclePanelLabel = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * The name of the vehicle. Defaults to "Add new vehicle"
     */
    this.vehicleLabel = 'Add new vehicle';
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-panel-label');
    customElements.whenDefined('bp-sdk-external-vehicle-panel-label').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return index.h("bp-sdk-external-vehicle-panel-label", { vehicleLabel: this.vehicleLabel });
  }
  renderInternal() {
    return (index.h("div", { class: "bp-sdk-vehicle-panel-label__container" }, index.h("span", null, this.vehicleLabel)));
  }
};
BpSdkVehiclePanelLabel.style = bpSdkVehiclePanelLabelCss;

exports.bp_sdk_vehicle_group = BpSdkVehicleGroup;
exports.bp_sdk_vehicle_panel = BpSdkVehiclePanel;
exports.bp_sdk_vehicle_panel_buttons = BpSdkVehiclePanelButtons;
exports.bp_sdk_vehicle_panel_container = BpSdkVehiclePanelContainer;
exports.bp_sdk_vehicle_panel_content = BpSdkVehiclePanelContent;
exports.bp_sdk_vehicle_panel_label = BpSdkVehiclePanelLabel;
