import { getPartnerEngineConfig, getVehicleOptionsYears, getVehicleSelectionState, loadConfigurations, loadFullVehicleOptions, loadMakes, loadModels, loadSingleApplicationForm, loadSingleQuestionSet, loadYears, resetSelectedVehicle, selectVehicle, setVehicleSelection, getDisplayFriendlyVehicleOptionsSelection, } from '@boldpenguin/sdk-redux';
import { LoadingStates, QuestionReferenceType, VehicleFlowTypes, VehicleTypes, YmmcUpdateType, } from '@boldpenguin/sdk-types';
import { focusErrors, getCommercialAutoFlowQuestion, getGroupId } from '@boldpenguin/sdk-utility';
import { Component, Element, Event, h, Listen, Prop, State, Watch } from '@stencil/core';
import { store } from '@stencil/redux';
import debounce from 'lodash/debounce';
import isEqual from 'lodash/isEqual';
import { canGetStore } from '../../utils/store';
export class BpSdkVehiclePanelContainer {
  constructor() {
    /**
     * Non-vehicle specific answers
     */
    this.answers = [];
    /**
     * Can delete
     */
    this.canDelete = false;
    /**
     * Vehicle options injected by redux
     */
    this.yearOptions = {};
    /**
     * Should show trailers?
     */
    this.shouldShowTrailers = false;
    /**
     * Is vehicle trailer?
     */
    this.isVehicleTrailer = false;
    this.vehicleInformation = {
      year: '',
      make: '',
      model: '',
      configuration: '',
    };
    this.canEdit = true;
    this.canSave = false;
    this.isEditing = false;
    this.isExpanded = true;
    this.isSaving = false;
    this.isValid = true;
    this.useExternal = false;
    this.tabIndex = 0;
    this.vehicleLabel = '';
    this.makeDisplayValue = '';
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        store.mapDispatchToProps(this, {
          loadYears,
          loadMakes,
          loadModels,
          loadConfigurations,
          loadSingleQuestionSet,
          loadSingleApplicationForm,
          selectVehicle,
          resetSelectedVehicle,
          loadFullVehicleOptions,
          setVehicleSelection,
        });
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        config: getPartnerEngineConfig(state),
        appFormId: state.application.form.id,
        yearOptions: getVehicleOptionsYears(state, this.questionGroupId),
        selectionStatus: getVehicleSelectionState(state, this.questionGroupId),
        vehicleInformation: getDisplayFriendlyVehicleOptionsSelection(state, this.questionGroupId),
      };
    };
    this.loadOptions = debounce((selection) => {
      this.loadFullVehicleOptions({
        year: selection.yearId,
        makeId: selection.makeId,
        modelId: selection.modelId,
        config: this.config,
        questionGroupId: this.questionGroupId,
        type: this.type,
      });
      this.setVehicleSelection({
        questionGroupId: this.questionGroupId,
        selection,
      });
    }, 100);
    this.setOptions = debounce((selection) => {
      this.setVehicleSelection({
        questionGroupId: this.questionGroupId,
        selection: Object.assign({ configurationId: undefined, makeId: undefined, modelId: undefined, yearId: undefined }, selection),
      });
    }, 100);
    this.onVehicleSaveCallback = () => {
      this.isSaving = false;
      this.isEditing = false;
      this.onQuestionGroupChange(this.questionGroup);
    };
    this.editVehicle = (e) => {
      e.stopPropagation();
      this.onEdit();
    };
    this.deleteVehicle = () => {
      this.deleteItem.emit(this.code);
      this.selectVehicle({
        answerPoolId: this.questionGroup.poolId,
        appId: this.appFormId,
        questionGroupId: this.questionGroup.groupId,
        configurationId: undefined,
        flowType: VehicleFlowTypes.ymm,
        config: this.config,
      });
    };
    this.onOpen = () => {
      this.canEdit = true;
      this.isEditing = false;
      this.isExpanded = true;
    };
    this.onClose = () => {
      this.canEdit = false;
      this.isEditing = false;
      this.isExpanded = false;
    };
  }
  resetState() {
    this.canEdit = true;
    this.canSave = false;
    this.isEditing = false;
    this.isExpanded = true;
    this.isValid = true;
    this.type = undefined;
    this.vehicleLabel = '';
    this.makeDisplayValue = '';
  }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-panel-container');
    customElements.whenDefined('bp-sdk-external-vehicle-panel-container').then(() => {
      this.useExternal = true;
    });
    this.onIsVehicleTrailerChanged(this.isVehicleTrailer);
    this.onTabChanged(this.tabIndex);
    this.onQuestionGroupChange(this.questionGroup);
  }
  handleTabChanged({ detail }) {
    if (this.useExternal) {
      return;
    }
    this.tabIndex = detail;
  }
  onTabChanged(tab) {
    this.updateType(tab, this.isVehicleTrailer);
  }
  onIsVehicleTrailerChanged(isVehicleTrailer) {
    this.updateType(this.tabIndex, isVehicleTrailer);
  }
  updateType(tab, isVehicleTrailer) {
    if (this.useExternal) {
      return;
    }
    const type = isVehicleTrailer || this.isTrailerTab(tab) ? VehicleTypes.trailers : undefined;
    if (type !== this.type) {
      this.setVehicleSelection({
        questionGroupId: this.questionGroupId,
        selection: { yearId: undefined, modelId: undefined, makeId: undefined, configurationId: undefined },
      });
      this.populateVehicleOptions(this.questionGroup);
      this.type = type;
      this.fetchYears();
    }
  }
  isTrailerTab(tab) {
    var _a;
    const flow = getCommercialAutoFlowQuestion(this.questionGroup);
    const trailerTab = flow === null || flow === void 0 ? void 0 : flow.question.choices.find((choice) => !!choice.value.match(/trailer/gi));
    const order = (_a = trailerTab === null || trailerTab === void 0 ? void 0 : trailerTab.order) !== null && _a !== void 0 ? _a : 2; // we know what order should be
    return tab === order;
  }
  populateVehicleOptions(questionGroup) {
    var _a, _b, _c, _d;
    const existingVehicleAnswer = (_a = questionGroup === null || questionGroup === void 0 ? void 0 : questionGroup.answers) === null || _a === void 0 ? void 0 : _a.find((ans) => ans.question.reference_type === QuestionReferenceType.CommercialAutoJson);
    if (!(existingVehicleAnswer === null || existingVehicleAnswer === void 0 ? void 0 : existingVehicleAnswer.value)) {
      return;
    }
    const vehicleJson = JSON.parse(existingVehicleAnswer.value);
    let year = Number(vehicleJson.year);
    let makeId = (_b = vehicleJson.make_id) === null || _b === void 0 ? void 0 : _b.toString();
    let modelId = (_c = vehicleJson.model_id) === null || _c === void 0 ? void 0 : _c.toString();
    let configurationId = (_d = vehicleJson.configuration_id) === null || _d === void 0 ? void 0 : _d.toString();
    //account for fallthrough free-text values for trailers
    if (vehicleJson.category === 'Trailers') {
      if (!makeId)
        makeId = vehicleJson.make;
      if (!modelId)
        modelId = vehicleJson.model;
    }
    const isValidState = !Number.isNaN(year) && makeId && modelId && (configurationId || vehicleJson.category === 'Trailers');
    this._currentYear = year;
    this._currentMakeId = makeId;
    this._currentModelId = modelId;
    this._currentConfigId = configurationId;
    this.canSave = this.isVehicleInputComplete();
    if (isValidState) {
      this.loadOptions({
        yearId: year,
        makeId,
        modelId,
        configurationId,
      });
    }
  }
  onQuestionGroupChange(questionGroup, oldQuestionGroup) {
    if (this.isSaving || isEqual(questionGroup, oldQuestionGroup)) {
      return;
    }
    this.questionGroupId = getGroupId(questionGroup);
    this.populateVehicleOptions(questionGroup);
    this.handleSubscriptions();
    this.vehicleLabel = this.getVehicleLabel();
    this.canSave = this.isVehicleInputComplete();
  }
  onVehicleInformationChange(vehicleInformation) {
    this.isValid = !!(vehicleInformation.make && vehicleInformation.model && vehicleInformation.year);
  }
  onOptionsUpdate(updateEvent) {
    var _a;
    const data = updateEvent.detail;
    if (!(data === null || data === void 0 ? void 0 : data.value)) {
      return;
    }
    switch (data.type) {
      case YmmcUpdateType.Year:
        const currentYear = Number(data.value);
        if (!Number.isNaN(currentYear) && currentYear) {
          this._currentYear = currentYear;
          this._currentMakeId = undefined;
          this._currentModelId = undefined;
          this._currentConfigId = undefined;
          this.setOptions({ yearId: currentYear });
          this.fetchMakes();
        }
        break;
      case YmmcUpdateType.Make:
        this._currentMakeId = data.value;
        this._currentModelId = undefined;
        this._currentConfigId = undefined;
        this.setOptions({ makeId: this._currentMakeId, yearId: this._currentYear });
        this.fetchModels();
        // Needed for free-form answer flows for trailers
        this.makeDisplayValue = (_a = data.displayValue) !== null && _a !== void 0 ? _a : '';
        break;
      case YmmcUpdateType.Model:
        this._currentModelId = data.value;
        this._currentConfigId = undefined;
        this.setOptions({
          modelId: this._currentModelId,
          makeId: this._currentMakeId,
          yearId: this._currentYear,
        });
        if (!this.isVehicleTrailer) {
          this.fetchConfigurations();
        }
        break;
      case YmmcUpdateType.Configuration:
        this._currentConfigId = data.value;
        this.setOptions({
          configurationId: this._currentConfigId,
          modelId: this._currentModelId,
          makeId: this._currentMakeId,
          yearId: this._currentYear,
        });
        break;
    }
    this.vehicleLabel = this.getVehicleLabel();
    this.canSave = this.isVehicleInputComplete();
  }
  fetchYears() {
    this.loadYears({ config: this.config, questionGroupId: this.questionGroupId });
  }
  fetchMakes() {
    this.loadMakes({
      config: this.config,
      questionGroupId: this.questionGroupId,
      type: this.type,
      year: this._currentYear,
    });
  }
  fetchModels() {
    this.loadModels({
      config: this.config,
      questionGroupId: this.questionGroupId,
      type: this.type,
      year: this._currentYear,
      makeId: this._currentMakeId,
    });
  }
  fetchConfigurations() {
    this.loadConfigurations({
      config: this.config,
      questionGroupId: this.questionGroupId,
      type: this.type,
      year: this._currentYear,
      makeId: this._currentMakeId,
      modelId: this._currentModelId,
    });
  }
  onMakeDirty() {
    if (!this.isValid && !this.isEditing && this.canEdit) {
      this.onEdit();
      setTimeout(() => focusErrors(), 200);
    }
  }
  onVinUpdate(event) {
    const answer = this.questionGroup.answers.find((ans) => ans.id === event.detail.answerId);
    if (answer != null) {
      this.saveAnswer.emit({ answer, new_value: event.detail.vin });
    }
  }
  onVehicleSave(saveEvent) {
    const flowType = saveEvent.detail;
    const isTrailerFlow = flowType === VehicleFlowTypes.trailers;
    const type = isTrailerFlow ? VehicleFlowTypes.trailers : undefined;
    const params = {
      answerPoolId: this.questionGroup.poolId,
      appId: this.appFormId,
      questionGroupId: this.questionGroup.groupId,
      configurationId: this._currentConfigId,
      flowType,
      config: this.config,
      type,
      callback: this.onVehicleSaveCallback,
    };
    if (flowType && (isTrailerFlow || this._currentConfigId)) {
      this.isSaving = true;
      if (isTrailerFlow && !this._currentConfigId) {
        /**
         * The vehicle params support the free-form text flow. They will be ignored if params.configurationId is defined.
         * In a free-form flow, PE uses the YMM values as-is, so we always need to pass them as the display values
         * instead of as IDs.
         *
         * The year id always matches the display value, so we can use that in any scenario.
         * If we are in a free-form flow, the model will always be a free-form answer. Therefore the id and display
         * values will match, and we can send the model id.
         * Make can be a dropdown option id or a free-form answer. If it is a dropdown option, the display value is the
         * text value we need to send to PE. If it is a free-form answer, the display value will match the id, and either
         * can be sent to PE. Therefore, we can safely choose the display value for either scenario.
         */
        params.vehicle = {
          yearId: this._currentYear,
          makeId: this.makeDisplayValue,
          modelId: this._currentModelId,
        };
      }
      this.selectVehicle(params);
    }
  }
  onVehicleResourceChange(vehicleSelectionState) {
    if (this.isEditing) {
      switch (vehicleSelectionState) {
        case LoadingStates.Loaded:
          this.resetSelectedVehicle({ questionGroupId: this.questionGroup.groupId });
          break;
      }
    }
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  onEdit() {
    if (!this.yearOptions || !Object.keys(this.yearOptions).length) {
      this.fetchYears();
    }
    this.isEditing = true;
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-vehicle-panel-container", { answers: this.answers, appFormId: this.appFormId, canDelete: this.canDelete, code: this.code, config: this.config, isVehicleTrailer: this.isVehicleTrailer, questionGroup: this.questionGroup, selectionStatus: this.selectionStatus, shouldShowTrailers: this.shouldShowTrailers, yearOptions: this.yearOptions, vehicleInformation: this.vehicleInformation, vehicleLabel: this.vehicleLabel }));
  }
  renderInternal() {
    return (h("bp-sdk-vehicle-panel", { answers: this.answers, canDelete: this.canDelete, canEdit: this.canEdit, canSave: this.canSave, code: this.code, handleClose: this.onClose, handleDelete: this.deleteVehicle, handleEdit: this.editVehicle, handleOpen: this.onOpen, isEditing: this.isEditing, isExpanded: this.isExpanded, isValid: this.isValid, questionGroup: this.questionGroup, isVehicleTrailer: this.isVehicleTrailer, shouldShowTrailers: this.shouldShowTrailers, vehicleInformation: this.vehicleInformation, vehicleLabel: this.vehicleLabel }));
  }
  getVehicleLabel() {
    var _a, _b, _c;
    // This is the anchor question. Its value should be the full vehicle name
    return (_c = (_b = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.parentQuestionAnswer) === null || _b === void 0 ? void 0 : _b.value) !== null && _c !== void 0 ? _c : '';
  }
  isVehicleInputComplete() {
    const hasTrailerValues = !!this._currentYear && !!this._currentMakeId && !!this._currentModelId;
    const canSaveTrailer = this.isVehicleTrailer && hasTrailerValues;
    return canSaveTrailer || !!this._currentConfigId;
  }
  static get is() { return "bp-sdk-vehicle-panel-container"; }
  static get originalStyleUrls() { return {
    "$": ["./bp-sdk-vehicle-panel-container.css"]
  }; }
  static get styleUrls() { return {
    "$": ["bp-sdk-vehicle-panel-container.css"]
  }; }
  static get properties() { return {
    "code": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Code"
      },
      "attribute": "code",
      "reflect": false
    },
    "answers": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IAnswer[]",
        "resolved": "IAnswer[]",
        "references": {
          "IAnswer": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Non-vehicle specific answers"
      },
      "defaultValue": "[]"
    },
    "questionGroup": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IMappedQuestionGroupAnswers",
        "resolved": "IMappedQuestionGroupAnswers",
        "references": {
          "IMappedQuestionGroupAnswers": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Question Group"
      }
    },
    "canDelete": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Can delete"
      },
      "attribute": "can-delete",
      "reflect": false,
      "defaultValue": "false"
    },
    "appFormId": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "App Form ID injected by redux"
      },
      "attribute": "app-form-id",
      "reflect": false
    },
    "config": {
      "type": "unknown",
      "mutable": true,
      "complexType": {
        "original": "IPartnerEngineConfig",
        "resolved": "IPartnerEngineConfig",
        "references": {
          "IPartnerEngineConfig": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "IPartnerEngineConfig injected from redux"
      }
    },
    "yearOptions": {
      "type": "unknown",
      "mutable": true,
      "complexType": {
        "original": "IVehicleYearOptions",
        "resolved": "IVehicleYearOptions",
        "references": {
          "IVehicleYearOptions": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Vehicle options injected by redux"
      },
      "defaultValue": "{}"
    },
    "selectionStatus": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "LoadingStates",
        "resolved": "LoadingStates.Error | LoadingStates.Loaded | LoadingStates.Loading | LoadingStates.NotLoaded",
        "references": {
          "LoadingStates": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Vehicle options resource injected by redux"
      },
      "attribute": "selection-status",
      "reflect": false
    },
    "shouldShowTrailers": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Should show trailers?"
      },
      "attribute": "should-show-trailers",
      "reflect": false,
      "defaultValue": "false"
    },
    "isVehicleTrailer": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Is vehicle trailer?"
      },
      "attribute": "is-vehicle-trailer",
      "reflect": false,
      "defaultValue": "false"
    },
    "vehicleInformation": {
      "type": "unknown",
      "mutable": true,
      "complexType": {
        "original": "IVehicleSummary",
        "resolved": "IVehicleSummary",
        "references": {
          "IVehicleSummary": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "defaultValue": "{\n    year: '',\n    make: '',\n    model: '',\n    configuration: '',\n  }"
    }
  }; }
  static get states() { return {
    "canEdit": {},
    "canSave": {},
    "isEditing": {},
    "isExpanded": {},
    "isSaving": {},
    "isValid": {},
    "useExternal": {},
    "_currentYear": {},
    "_currentMakeId": {},
    "_currentModelId": {},
    "_currentConfigId": {},
    "questionGroupId": {},
    "type": {},
    "tabIndex": {},
    "vehicleLabel": {}
  }; }
  static get events() { return [{
      "method": "deleteItem",
      "name": "deleteItem",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      }
    }, {
      "method": "saveAnswer",
      "name": "saveAnswer",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Passes information needed to update answer"
      },
      "complexType": {
        "original": "{\n    answer: IAnswer;\n    new_value: string | string[];\n  }",
        "resolved": "{ answer: IAnswer; new_value: string | string[]; }",
        "references": {
          "IAnswer": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      }
    }]; }
  static get elementRef() { return "el"; }
  static get watchers() { return [{
      "propName": "tabIndex",
      "methodName": "onTabChanged"
    }, {
      "propName": "isVehicleTrailer",
      "methodName": "onIsVehicleTrailerChanged"
    }, {
      "propName": "questionGroup",
      "methodName": "onQuestionGroupChange"
    }, {
      "propName": "vehicleInformation",
      "methodName": "onVehicleInformationChange"
    }, {
      "propName": "selectionStatus",
      "methodName": "onVehicleResourceChange"
    }]; }
  static get listeners() { return [{
      "name": "tabChanged",
      "method": "handleTabChanged",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "ymmcUpdate",
      "method": "onOptionsUpdate",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "makeDirty",
      "method": "onMakeDirty",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "vinUpdate",
      "method": "onVinUpdate",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "saveVehicle",
      "method": "onVehicleSave",
      "target": undefined,
      "capture": false,
      "passive": false
    }]; }
}
