import { r as registerInstance, h } from './index-b4e0290f.js';
import { saveQuestionSet, updateErrors, removeActiveAnswerId, switchActiveQuestionSet, getCurrentActiveQuestionSet, getPartnerEngineConfig, getQuestionSets, getAnswersState, getApplicationFormState, getQuestionPoolState, getQuestionSetState } from '@boldpenguin/sdk-redux';
import { i } from './index.esm.min-622418b4.js';
import { c as canGetStore, s as store } from './store-6dda1ad2.js';

const bpSdkBackButtonContainerCss = "";

let BpSdkBackButtonContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * Controls disabled state of button
     */
    this.buttonDisabled = false;
    /**
     * Question sets
     */
    this.questionSets = [];
    this.useExternal = false;
    this.canSave = true;
    this.areResourcesReady = true;
    this.isReady = true;
    this.isFirstRun = true;
    this.isFirstQnSet = true;
    this.isDisabled = false;
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        if (this.storeUnsubscribe) {
          this.storeUnsubscribe();
        }
        store.mapDispatchToProps(this, {
          saveQuestionSet,
          updateErrors,
          removeActiveAnswerId,
          switchActiveQuestionSet,
        });
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        activeQuestionSet: getCurrentActiveQuestionSet(state),
        config: getPartnerEngineConfig(state),
        questionSets: getQuestionSets(state),
        queue: state.queues.answers.queue,
        answersResourceState: getAnswersState(state),
        applicationFormResourceState: getApplicationFormState(state),
        questionPoolResourceState: getQuestionPoolState(state),
        questionSetResourceState: getQuestionSetState(state),
      };
    };
  }
  resetState() { }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-back-button-container');
    customElements.whenDefined('bp-sdk-external-back-button-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
    this.onQuestionSetsChange(this.questionSets);
    this.onActiveQuestionSetChange(this.activeQuestionSet);
    this.onIsReady(this.isReady);
    this.onAnswersResourcesStateChange(this.answersResourceState);
    this.onApplicationFormResourceStateChange(this.applicationFormResourceState);
    this.onIsFirstRun(this.isFirstRun);
    this.onIsReady(this.isReady);
    this.onQuestionPoolResourcesStateChange(this.questionPoolResourceState);
    this.onQuestionSetResourcesStateChange(this.questionSetResourceState);
    this.onQueueChange(this.queue);
  }
  onIsReady(isReady) {
    this.updateAreResourcesReady(this.isFirstRun, isReady);
  }
  updateAreResourcesReady(isFirstRun, isReady) {
    this.areResourcesReady = isFirstRun || isReady;
  }
  onAnswersResourcesStateChange(state) {
    this.isReady = this.calculateResourcesReady({
      answers: state,
      applicationForm: this.applicationFormResourceState,
      questionPools: this.questionPoolResourceState,
      questionSets: this.questionSetResourceState,
    });
  }
  onApplicationFormResourceStateChange(state) {
    if (this.isFirstRun && state === i.Loaded) {
      this.isFirstRun = false;
    }
    this.isReady = this.calculateResourcesReady({
      answers: this.answersResourceState,
      applicationForm: state,
      questionPools: this.questionPoolResourceState,
      questionSets: this.questionSetResourceState,
    });
  }
  onQuestionPoolResourcesStateChange(state) {
    this.isReady = this.calculateResourcesReady({
      answers: this.answersResourceState,
      applicationForm: this.applicationFormResourceState,
      questionPools: state,
      questionSets: this.questionSetResourceState,
    });
  }
  onQuestionSetResourcesStateChange(state) {
    this.isReady = this.calculateResourcesReady({
      answers: this.answersResourceState,
      applicationForm: this.applicationFormResourceState,
      questionPools: this.questionPoolResourceState,
      questionSets: state,
    });
  }
  calculateResourcesReady(resources = {}) {
    if (!resources ||
      resources.applicationForm !== i.Loaded ||
      resources.answers === i.Loading ||
      resources.questionPools === i.Loading ||
      resources.questionSets === i.Loading) {
      return false;
    }
    return true;
  }
  onActiveQuestionSetChange(activeQuestionSet) {
    this.updateIsFirstQnSet(this.questionSets, activeQuestionSet);
  }
  onIsFirstRun(isFirstRun) {
    this.updateAreResourcesReady(isFirstRun, this.isReady);
  }
  onQuestionSetsChange(qns) {
    this.updateIsFirstQnSet(qns, this.activeQuestionSet);
  }
  updateIsFirstQnSet(qns, activeQns) {
    var _a;
    this.isFirstQnSet = ((_a = qns[0]) === null || _a === void 0 ? void 0 : _a.question_set_id) === (activeQns === null || activeQns === void 0 ? void 0 : activeQns.question_set_id);
  }
  onQueueChange(queue) {
    this.canSave = !(queue === null || queue === void 0 ? void 0 : queue.length);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-back-button-container", { activeQuestionSet: this.activeQuestionSet, answersResourceState: this.answersResourceState, applicationFormResourceState: this.applicationFormResourceState, buttonDisabled: this.buttonDisabled, config: this.config, questionPoolResourceState: this.questionPoolResourceState, questionSetResourceState: this.questionSetResourceState, questionSets: this.questionSets, queue: this.queue }));
  }
  handleNavigateBack() {
    this.switchActiveQuestionSet('backward');
  }
  renderInternal() {
    return (h("bp-sdk-back-button", { buttonDisabled: this.buttonDisabled || !this.areResourcesReady || !this.canSave || this.isFirstQnSet, cssClasses: !this.areResourcesReady || !this.canSave ? 'loading' : 'not-loading' }));
  }
  static get watchers() { return {
    "isReady": ["onIsReady"],
    "answersResourceState": ["onAnswersResourcesStateChange"],
    "applicationFormResourceState": ["onApplicationFormResourceStateChange"],
    "questionPoolResourceState": ["onQuestionPoolResourcesStateChange"],
    "questionSetResourceState": ["onQuestionSetResourcesStateChange"],
    "activeQuestionSet": ["onActiveQuestionSetChange"],
    "isFirstRun": ["onIsFirstRun"],
    "questionSets": ["onQuestionSetsChange"],
    "queue": ["onQueueChange"]
  }; }
};
BpSdkBackButtonContainer.style = bpSdkBackButtonContainerCss;

export { BpSdkBackButtonContainer as bp_sdk_back_button_container };
